@@ -43,6 +43,7 @@ from svc_infra.apf_payments.schemas import (
     UsageRecordListFilter,
     UsageRecordOut,
     WebhookAckOut,
+    WebhookReplayIn,
     WebhookReplayOut,
 )
 from svc_infra.apf_payments.service import PaymentsService
@@ -76,6 +77,7 @@ async def get_service(session: SqlSessionDep) -> PaymentsService:
 def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
     routers: list[DualAPIRouter] = []
 
+    pub = public_router(prefix=prefix)
     user = user_router(prefix=prefix)
     svc = service_router(prefix=prefix)
     prot = protected_router(prefix=prefix)
@@ -198,9 +200,6 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
 
     routers.append(prot)
 
-    # PUBLIC webhooks
-    pub = public_router(prefix=prefix, tags=["payments"])
-
     @pub.post(
         "/webhooks/{provider}",
         name="payments_webhook",
@@ -435,7 +434,7 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
         return await svc.get_intent(provider_intent_id)
 
     # STATEMENTS (rollup)
-    @svc.get(
+    @prot.get(
         "/statements/daily",
         response_model=list[StatementRow],
         name="payments_daily_statements",
@@ -629,7 +628,7 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
         return out
 
     # ===== Disputes =====
-    @svc.get(
+    @prot.get(
         "/disputes",
         name="payments_list_disputes",
         response_model=Paginated[DisputeOut],
@@ -646,7 +645,7 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
         )
         return ctx.wrap(items, next_cursor=next_cursor)
 
-    @svc.get(
+    @prot.get(
         "/disputes/{provider_dispute_id}",
         name="payments_get_dispute",
         response_model=DisputeOut,
@@ -655,7 +654,7 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
     async def get_dispute(provider_dispute_id: str, svc: PaymentsService = Depends(get_service)):
         return await svc.get_dispute(provider_dispute_id)
 
-    @svc.post(
+    @prot.post(
         "/disputes/{provider_dispute_id}/submit_evidence",
         name="payments_submit_dispute_evidence",
         dependencies=[Depends(require_idempotency_key)],
@@ -672,13 +671,13 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
         return out
 
     # ===== Balance & Payouts =====
-    @svc.get(
+    @prot.get(
         "/balance", name="payments_get_balance", response_model=BalanceSnapshotOut, tags=["Balance"]
     )
     async def get_balance(svc: PaymentsService = Depends(get_service)):
         return await svc.get_balance_snapshot()
 
-    @svc.get(
+    @prot.get(
         "/payouts",
         name="payments_list_payouts",
         response_model=Paginated[PayoutOut],
@@ -710,10 +709,10 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
     async def replay_webhooks(
         since: Optional[str] = None,
         until: Optional[str] = None,
-        event_ids: Optional[list[str]] = Body(default=None),
+        data: WebhookReplayIn = Body(default=WebhookReplayIn()),
         svc: PaymentsService = Depends(get_service),
     ):
-        count = await svc.replay_webhooks(since, until, event_ids or [])
+        count = await svc.replay_webhooks(since, until, data.event_ids or [])
         await svc.session.flush()
         return {"replayed": count}
 
@@ -787,7 +786,7 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
     ):
         return await svc.get_product(provider_product_id)
 
-    @svc.get(
+    @prot.get(
         "/products",
         response_model=Paginated[ProductOut],
         name="payments_list_products",
@@ -821,7 +820,7 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
         return out
 
     # ===== Prices: get/list/update (active toggle) =====
-    @svc.get(
+    @prot.get(
         "/prices/{provider_price_id}",
         response_model=PriceOut,
         name="payments_get_price",
@@ -832,7 +831,7 @@ def build_payments_routers(prefix: str = "/payments") -> list[DualAPIRouter]:
     ):
         return await svc.get_price(provider_price_id)
 
-    @svc.get(
+    @prot.get(
         "/prices",
         response_model=Paginated[PriceOut],
         name="payments_list_prices",
