@@ -17,7 +17,7 @@ _pwd = PasswordHelper()
 _DUMMY_BCRYPT = _pwd.hash("dummy-password")
 
 
-async def login_client_guard(request: Request):
+async def login_client_gaurd(request: Request):
     """
     If AUTH_REQUIRE_CLIENT_SECRET_ON_PASSWORD_LOGIN is True,
     require client_id/client_secret on POST .../login requests.
@@ -60,10 +60,9 @@ def auth_session_router(
     auth_backend: AuthenticationBackend,
     user_model: type,
     get_mfa_pre_writer,
-    public_auth_prefix: str = "/auth",
     auth_policy: AuthPolicy | None = None,
 ) -> APIRouter:
-    router = public_router(prefix=public_auth_prefix, tags=["auth:session"])
+    router = public_router()
     policy = auth_policy or DefaultAuthPolicy(get_auth_settings())
 
     @router.post("/login", name="auth:jwt.login")
